@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 #
-# -- General configuration -----------------------------------------------------
+# -- General configuration -------------------------------------
 
 source_suffix = '.rst'
 master_doc = 'index'
 
-project = u'sphinx theme for Business style'
+project = u'Sphinx theme for Business style'
 copyright = u'2011, Sphinx-users.jp'
 
-version = '0.1.0'
+version = '0.1.4'
 
-# -- Options for HTML output ---------------------------------------------------
+# -- Options for HTML output -----------------------------------
 
 extensions = ['sphinxjp.themecore']
 html_theme = 'bizstyle'
